@@ -1,6 +1,6 @@
 package Net::Appliance::Session::Transport;
-BEGIN {
-  $Net::Appliance::Session::Transport::VERSION = '3.112610';
+{
+  $Net::Appliance::Session::Transport::VERSION = '3.113600';
 }
 
 {
@@ -21,6 +21,13 @@ BEGIN {
         required => 0,
         predicate => 'has_password',
     );
+
+    has privileged_password => (
+        is => 'ro',
+        isa => 'Str',
+        required => 0,
+        predicate => 'has_privileged_password',
+    );
 }
 
 use Moose::Role;
@@ -29,8 +36,11 @@ sub connect {
     my $self = shift;
     my $options = Net::Appliance::Session::Transport::ConnectOptions->new(@_);
 
-    $self->set_username($options->username) if $options->has_username;
-    $self->set_password($options->password) if $options->has_password;
+    foreach my $slot (qw/ username password privileged_password /) {
+        my $has = 'has_' . $slot;
+        my $set = 'set_' . $slot;
+        $self->$set($options->$slot) if $options->$has;
+    }
 
     # SSH transport takes a username if we have one
     $self->nci->transport->connect_options->username($self->get_username)
@@ -86,6 +96,12 @@ sub close {
     # re-enable paging
     $self->enable_paging if $self->do_paging;
 
+    # issue disconnect macro if the phrasebook has one
+    if ($self->nci->phrasebook->has_macro('disconnect')) {
+        eval { $self->macro('disconnect') };
+        # this should die as there's no returned prompt (NCI pump() fails)
+    }
+
     $self->nci->transport->disconnect;
     $self->logged_in(0);
 }
